//
//  CarTableViewController.swift
//  Showroom
//
//  Created by Holger Hinzberg on 15.11.15.
//  Copyright © 2015 Holger Hinzberg. All rights reserved.
//

import UIKit

class CarTableViewController: UITableViewController
{
    private var showroom:ShowroomRepository?
    private var selectedCar:ShowroomCar?
    private let detailSegueIdentifier = "CarDetailsSegue"
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        let sharedDelegate = UIApplication.sharedApplication().delegate
        let appDelegate = sharedDelegate as? AppDelegate
        showroom = appDelegate?.repository
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView
        (tableView: UITableView) -> Int
    {
        return 1
    }

    override func tableView
        (tableView: UITableView, numberOfRowsInSection section: Int) -> Int
    {
        // Die Anzahl der Objekte in der Tabelle
        // entspricht der Anzahl der Objekte im Repository.
        return self.showroom!.itemsCount()
    }

    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell
    {
        let cell
        = tableView.dequeueReusableCellWithIdentifier(
            "CarCell", forIndexPath: indexPath)
        
        // Ein Fahrzeug für die angegebene Zeile aus
        // dem Repository holen
        let car
        = self.showroom?.itemAtIndex(indexPath.row)
        
        if car != nil
        {
            // Aus Marke und Modell eine Bezeichnung
            // zusammensetzen
            let description = "\(car!.make) \(car!.model)"
            
            // Der Zelle die Bezeichnung zuweisen
            cell.textLabel?.text  = description;
        }
        
        return cell
    }

    override func tableView(tableView:
        UITableView, didSelectRowAtIndexPath
        indexPath: NSIndexPath)
    {
        // Das gewählte Fahrzeug merken
        self.selectedCar
            = self.showroom?.itemAtIndex(indexPath.row)
        
        // Den Segue für die Detailansicht starten
        self.performSegueWithIdentifier(
            self.detailSegueIdentifier, sender: self)
    }
    
    override func prepareForSegue(segue:
        UIStoryboardSegue, sender: AnyObject?)
    {
        // Ist es der Segue für die Detailansicht?
        if segue.identifier == self.detailSegueIdentifier
        {
            // Das gemerkte Fahrzeug an die
            // Detailansicht übergeben
            if let detailView = segue.destinationViewController
                as? CarDetailViewController
            {
                detailView.car = self.selectedCar
            }
        }
    }


    /*
    // Override to support conditional editing of the table view.
    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return false if you do not want the specified item to be editable.
        return true
    }
    */

    /*
    // Override to support editing the table view.
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            // Delete the row from the data source
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
        } else if editingStyle == .Insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }
    */

    /*
    // Override to support rearranging the table view.
    override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return false if you do not want the item to be re-orderable.
        return true
    }
    */



}
